@@ -21,7 +21,7 @@ Image::load(::java::lang::String* filePath)
 	Surface* result = NULL;
 
 	jbyteArray byteArray = filePath->getBytes();
-	int length = byteArray->length;
+	int length = JvGetArrayLength(byteArray);
 	jbyte* bytes = elements(byteArray);
 	char buffer[length+1];
 
