@@ -21,7 +21,7 @@ public class Palette
 
 	public Palette(int size)
 	{
-		this.initializePalette(size);
+		this.initPalette(size);
 	}
 
 	public Palette(Color[] colors)
@@ -73,6 +73,12 @@ public class Palette
 		return buffer.toString();
 	}
 
-	protected native void initializePalette(int size);
-	protected native void finalizePalette();
+	public void finalize() throws Throwable
+	{
+		this.freePalette();
+		super.finalize();
+	}
+
+	protected native void initPalette(int size);
+	protected native void freePalette();
 }
