@@ -54,12 +54,9 @@ Palette::setColorAt (jint index, jint red, jint green, jint blue)
 }
 
 void 
-Palette::initializePalette (jint size)
+Palette::initPalette (jint size)
 {
-	if (this->colors != NULL) 
-	{
-		this->finalizePalette();
-	}
+	this->freePalette();
 
 	SDL_Color* nativeColors;
 	nativeColors = (SDL_Color*)JvMalloc(sizeof(SDL_Color) * size);
@@ -78,7 +75,7 @@ Palette::initializePalette (jint size)
 }
 
 void 
-Palette::finalizePalette ()
+Palette::freePalette ()
 {
 	if (this->colors != NULL) 
 	{
