@@ -5,10 +5,40 @@ import java.io.File;
 public class Screen extends Surface
 {
 	// class methods
+	/**
+	* Check to see if a particular video mode is supported.
+	* SDL_VideoModeOK(int w, int h, int bpp, int flags) wrapper.
+	* @return 0 if the requested mode is not supported under any bit depth,
+	*  or returns the bits-per-pixel of the closest available mode
+	*  with the given size and flags.
+	* @see VideoConstants.SDL_SWSURFACE
+	* @see VideoConstants.SDL_HWSURFACE
+	* @see VideoConstants.SDL_ASYNCBLIT
+	* @see VideoConstants.SDL_ANYFORMAT
+	* @see VideoConstants.SDL_HWPALETTE
+	* @see VideoConstants.SDL_DOUBLEBUF
+	* @see VideoConstants.SDL_FULLSCREEN
+	* @see VideoConstants.SDL_OPENGL
+	* @see VideoConstants.SDL_OPENGLBLIT
+	* @see VideoConstants.SDL_RESIZABLE
+	* @see VideoConstants.SDL_NOFRAME
+	**/
+	public static native int videoModeOK(int width, int height, int bpp, int flags);
 
 	/**
 	* Set up a video mode with the specified width, height and bits-per-pixel.
 	* SDL_SetVideoMode(int w, int h, int bpp, int flags) wrapper.
+	* @see VideoConstants.SDL_SWSURFACE
+	* @see VideoConstants.SDL_HWSURFACE
+	* @see VideoConstants.SDL_ASYNCBLIT
+	* @see VideoConstants.SDL_ANYFORMAT
+	* @see VideoConstants.SDL_HWPALETTE
+	* @see VideoConstants.SDL_DOUBLEBUF
+	* @see VideoConstants.SDL_FULLSCREEN
+	* @see VideoConstants.SDL_OPENGL
+	* @see VideoConstants.SDL_OPENGLBLIT
+	* @see VideoConstants.SDL_RESIZABLE
+	* @see VideoConstants.SDL_NOFRAME
 	**/
 	public static native Screen setVideoMode(int width, int height, int bpp, int flags);
 
@@ -267,9 +297,29 @@ public class Screen extends Surface
 	**/
 	public native boolean getGrabInputMode();
 
+	public void freeSurface(){}
+
+	public void displayFormat(){}
+
+	public void displayForamtAlpha(){}
+
 	public void convertSurface(PixelFormat format, int flags){}
 
-	public void freeSurface(){}
+	protected void initRGBSurface(int flags, 
+		int width, int height, int bpp,
+		int rmask, int gmask, int bmask, int amask){}
+
+	protected void initRGBSurfaceFrom(byte[] pixels,
+		int width, int height, int bpp, int pitch,
+		int rmask, int gmask, int bmask, int amask){}
+
+	protected void initRGBSurfaceFrom(short[] pixels,
+		int width, int height, int bpp, int pitch,
+		int rmask, int gmask, int bmask, int amask){}
+
+	protected void initRGBSurfaceFrom(int[] pixels,
+		int width, int height, int bpp, int pitch,
+		int rmask, int gmask, int bmask, int amask){}
 
 }
 
