@@ -30,6 +30,13 @@ createIllegalStateScreenException()
 }
 
 // class methods
+jint
+Screen::videoModeOK(jint width, jint height, jint bpp, jint flags)
+{
+	JvInitClass(&Screen::class$);
+	return ::SDL_VideoModeOK(width, height, bpp, flags);
+}
+
 Screen* 
 Screen::setVideoMode (jint width, jint height, jint bpp, jint flags)
 {
@@ -174,7 +181,7 @@ Screen::setCaption (jstring windowCaption, jstring iconCaption)
 	{
 		jbyteArray byteArray = windowCaption->getBytes();
 		jbyte* bytes = elements(byteArray);
-		int length = byteArray->length;
+		int length = JvGetArrayLength(byteArray);
 		char buffer[length+1];
 
 		memcpy(buffer, bytes, length);
@@ -186,7 +193,7 @@ Screen::setCaption (jstring windowCaption, jstring iconCaption)
 	{
 		jbyteArray byteArray = iconCaption->getBytes();
 		jbyte* bytes = elements(byteArray);
-		int length = byteArray->length;
+		int length = JvGetArrayLength(byteArray);
 		char buffer[length+1];
 
 		memcpy(buffer, bytes, length);
@@ -236,9 +243,7 @@ Screen::setIcon(Surface* icon, jbyteArray mask)
 	if (mask != NULL)
 	{
 		int length = (nativeIcon->w + 7) / 8 * nativeIcon->h;
-		//printf("nativeIcon->w : %d, nativeIcon->h : %d\n", nativeIcon->w, nativeIcon->h);
-		//printf("length %d, mask->length %d\n", length, mask->length);
-		if(mask->length < length)
+		if(JvGetArrayLength(mask) < length)
 			throw new SDLException(JvNewStringLatin1("The mask array size is too small."));
 		nativeMask = (Uint8*)elements(mask);
 	}
@@ -333,7 +338,7 @@ Screen::toggleFullScreen ()
 {
 	if (this->implementation == NULL) throw createIllegalStateScreenException();
 	SDL_Surface* nativeScreen = (SDL_Surface*)this->implementation;
-	::SDL_WM_ToggleFullScreen(nativeScreen);
+	return ::SDL_WM_ToggleFullScreen(nativeScreen);
 }
 
 jboolean
