@@ -22,6 +22,14 @@ createFreedSurfaceException()
 	return new sdl4gcj::SDLException(JvNewStringLatin1("This Surface was already freed."));
 }
 
+static
+inline
+sdl4gcj::SDLException*
+createSmallPixelArrayException()
+{
+	return new sdl4gcj::SDLException(JvNewStringLatin1("Pixels array is too small."));
+}
+
 // class methods
 ::java::lang::String*
 Surface::getVideoDriverName()
@@ -43,7 +51,7 @@ Surface::loadBMP(::java::lang::String* filePath)
 	Surface* result = NULL;
 
 	jbyteArray byteArray = filePath->getBytes();
-	int length = byteArray->length;
+	int length = JvGetArrayLength(byteArray);
 	jbyte* bytes = elements(byteArray);
 	char buffer[length+1];
 
@@ -117,7 +125,7 @@ Surface::saveBMP(::java::lang::String* filePath)
 {
 	if (this->implementation == NULL) throw createFreedSurfaceException();
 	jbyteArray byteArray = filePath->getBytes();
-	int length = byteArray->length;
+	int length = JvGetArrayLength(byteArray);
 	jbyte* bytes = elements(byteArray);
 	char buffer[length+1];
 
@@ -301,6 +309,7 @@ Surface::displayFormat ()
 
 	SDL_FreeSurface(nativeSurface);
 	this->implementation = (::gnu::gcj::RawData*)newNativeSurface;
+	this->pixelArray = NULL;
 	this->format = NULL;
 }
 
@@ -315,6 +324,7 @@ Surface::displayForamtAlpha ()
 
 	SDL_FreeSurface(nativeSurface);
 	this->implementation = (::gnu::gcj::RawData*)newNativeSurface;
+	this->pixelArray = NULL;
 	this->format = NULL;
 }
 
@@ -333,6 +343,7 @@ Surface::convertSurface (PixelFormat* format, jint flags)
 
 	SDL_FreeSurface(nativeSurface);
 	this->implementation = (::gnu::gcj::RawData*)newNativeSurface;
+	this->pixelArray = NULL;
 	this->format = NULL;
 }
 
@@ -463,16 +474,95 @@ Surface::freeSurface()
 }
 
 void
-Surface::initWithRGBSurface( jint flags, 
+Surface::initRGBSurface( jint flags, 
 		jint width, jint height, jint bpp,
 		jint rmask, jint gmask, jint bmask, jint amask)
 {
 	SDL_Surface* nativeSurface = NULL;
 
-	nativeSurface = SDL_CreateRGBSurface(flags, width, height, bpp,
+	nativeSurface = SDL_CreateRGBSurface(flags,
+		width, height, bpp,
 		rmask, gmask, bmask, amask);
 	if (nativeSurface != NULL)
 	{
+		this->freeSurface();
+		this->pixelArray = NULL;
+		this->format = NULL;
+		this->implementation = (::gnu::gcj::RawData*)nativeSurface;
+	}
+
+	return ;
+}
+
+void
+Surface::initRGBSurfaceFrom(jbyteArray pixels,
+		jint width, jint height, jint bpp, jint pitch,
+		jint rmask, jint gmask, jint bmask, jint amask)
+{
+	SDL_Surface* nativeSurface = NULL;
+
+	if ((jint)(JvGetArrayLength(pixels) * sizeof(jbyte)) < (pitch * height))
+		throw createSmallPixelArrayException();
+
+	nativeSurface = SDL_CreateRGBSurfaceFrom((void*)elements(pixels),
+		width, height, bpp, pitch,
+		rmask, gmask, bmask, amask);
+	if (nativeSurface != NULL)
+	{
+		this->freeSurface();
+		this->pixelArray = NULL;
+		this->format = NULL;
+		this->sourceArray = pixels;
+		this->implementation = (::gnu::gcj::RawData*)nativeSurface;
+	}
+
+	return ;
+}
+
+void
+Surface::initRGBSurfaceFrom(jshortArray pixels,
+		jint width, jint height, jint bpp, jint pitch,
+		jint rmask, jint gmask, jint bmask, jint amask)
+{
+	SDL_Surface* nativeSurface = NULL;
+
+	if ((jint)(JvGetArrayLength(pixels) * sizeof(jshort)) < pitch * height)
+		throw createSmallPixelArrayException();
+
+	nativeSurface = SDL_CreateRGBSurfaceFrom((void*)elements(pixels),
+		width, height, bpp, pitch,
+		rmask, gmask, bmask, amask);
+	if (nativeSurface != NULL)
+	{
+		this->freeSurface();
+		this->pixelArray = NULL;
+		this->format = NULL;
+		this->sourceArray = pixels;
+		this->implementation = (::gnu::gcj::RawData*)nativeSurface;
+	}
+
+	return ;
+}
+
+void
+Surface::initRGBSurfaceFrom(jintArray pixels,
+		jint width, jint height, jint bpp, jint pitch,
+		jint rmask, jint gmask, jint bmask, jint amask)
+{
+	SDL_Surface* nativeSurface = NULL;
+
+	if ((int)(JvGetArrayLength(pixels) * sizeof(jint)) < pitch * height)
+		throw createSmallPixelArrayException();
+
+	nativeSurface = SDL_CreateRGBSurfaceFrom(
+		(void*)elements(pixels),
+		width, height, bpp, pitch,
+		rmask, gmask, bmask, amask);
+	if (nativeSurface != NULL)
+	{
+		this->freeSurface();
+		this->pixelArray = NULL;
+		this->sourceArray = pixels;
 		this->implementation = (::gnu::gcj::RawData*)nativeSurface;
 	}
 
