@@ -143,7 +143,7 @@ public class TestSpriteGL extends GL implements SDLConstants
 
 	protected void setUp()
 	{
-		screen.showCursor(false);
+		Cursor.setVisible(false);
 		// init gl screen
 		glViewport(0, 0, screen.getW(), screen.getH());
 		glMatrixMode(GL_PROJECTION);
