@@ -1,7 +1,7 @@
 
 import java.util.HashMap;
 import java.util.Map;
-import sdl4gcj.Sys;
+import sdl4gcj.SDLSystem;
 import sdl4gcj.video.*;
 import sdl4gcj.event.*;
 import sdl4gcj.input.*;
@@ -578,7 +578,7 @@ public class JoystickTest
 	static final int WAIT_TIME = 30;
 	public static void main(String[] args)
 	{
-		if (Sys.init(Sys.SDL_INIT_VIDEO|Sys.SDL_INIT_JOYSTICK) != 0)
+		if (SDLSystem.init(SDLSystem.SDL_INIT_VIDEO|SDLSystem.SDL_INIT_JOYSTICK) != 0)
 		{
 			System.out.println("Init() fail");
 			System.exit(0);
@@ -617,7 +617,7 @@ public class JoystickTest
 		}
 		finally
 		{
-			Sys.quit();
+			SDLSystem.quit();
 		}
 	}
 }
